﻿using Microsoft.Extensions.Options;
using XF.Domain.Dependency;

namespace DataSharing
{
    /// <summary>
    /// 获取配置
    /// </summary>
    public class ChannelConfigurationManager : IChannelConfigurationManager, IScopeDependency
    {
        private readonly IOptionsSnapshot<ChannelConfiguration> _channelOption;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="channelOption"></param>
        public ChannelConfigurationManager(IOptionsSnapshot<ChannelConfiguration> channelOption)
        {
            _channelOption = channelOption;
        }

        /// <summary>
        /// 省12345
        /// </summary>
        /// <returns></returns>
        public ConfigurationProvince GetConfigurationProvince()
        {
            return _channelOption.Value.Province;
        }

        /// <summary>
        /// 企业服务
        /// </summary>
        /// <returns></returns>
        public ConfigurationEnterprise GetConfigurationEnterprise()
        {
            return _channelOption.Value.Enterprise;
        }

        /// <summary>
        /// 市州数据交换
        /// </summary>
        /// <returns></returns>
        public ConfigurationCityHandOver GetConfigurationCityHandOver()
        {
            return _channelOption.Value.CityHandOver;
        }

        /// <summary>
        /// 融媒体
        /// </summary>
        /// <returns></returns>
        public ConvergenceMediaCode GetConfigurationMediaCode()
        {
            return _channelOption.Value.MediaCode;
        }

        /// <summary>
        /// 系统市州编码
        /// </summary>
        /// <returns></returns>
        public ConfigurationCityCode GetConfigurationCityCode()
        {
            return _channelOption.Value.CityCode;
        }

        /// <summary>
        /// 道枢110
        /// </summary>
        /// <returns></returns>
        public ConfigurationPoliceDS GetConfigurationPoliceDS()
        {
            return _channelOption.Value.PoliceDS;
        }

        /// <summary>
        /// 业务系统附件上传配置
        /// </summary>
        /// <returns></returns>
        public ConfigurationBusinessFile GetConfigurationBusinessFile()
        {
            return _channelOption.Value.BusinessFile;
        }

        /// <summary>
        /// 门户网站配置
        /// </summary>
        /// <returns></returns>
        public ConfigurationWebPortal GetConfigurationWebPortal()
        {
            return _channelOption.Value.WebPortal;
        }

        /// <summary>
        /// 新老数据交换
        /// </summary>
        /// <returns></returns>
        public ConfigurationSendDataOld GetConfigurationSendDataOld()
        {
            return _channelOption.Value.SendDataOld;
        }

        /// <summary>
        /// 写入工单数据
        /// </summary>
        /// <returns></returns>
        public ConfigurationHotlineClient GetConfigurationHotlineClient()
        {
            return _channelOption.Value.HotlineClient;
        }

        
    }
}
