﻿using DataSharing.SendTask;
using DataSharing.Share.Dtos.DataExchange;
using Microsoft.Extensions.Logging;
using XF.Domain.Dependency;
using XF.Domain.Repository;

namespace DataSharing.DataExchange
{
    public class DataExchangePusherProviderService : IDataExchangePusherProviderService, IScopeDependency
    {
        private readonly ILogger<DataExchangePusherProviderService> _logger;
        private readonly DataExchangeClient _dataExchangeClient;
        private readonly IRepository<DsSendTask> _dsSendTaskRepository;
        private readonly IChannelConfigurationManager _channelConfigurationManager;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="logger"></param>
        /// <param name="dataExchangeClient"></param>
        /// <param name="dsSendTaskRepository"></param>
        public DataExchangePusherProviderService(ILogger<DataExchangePusherProviderService> logger,
             DataExchangeClient dataExchangeClient,
            IRepository<DsSendTask> dsSendTaskRepository,
            IChannelConfigurationManager channelConfigurationManager)
        {
            _logger = logger;
            _dataExchangeClient = dataExchangeClient;
            _dsSendTaskRepository = dsSendTaskRepository;
            _channelConfigurationManager = channelConfigurationManager;
        }

        /// <summary>
        /// 市州数据交换推送数据
        /// </summary>
        /// <param name="dto"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task SendDataExchangeDataPusher(DsSendTask dto, CancellationToken cancellationToken)
        {
            if (dto is null)
                return;

            var config = _channelConfigurationManager.GetConfigurationCityHandOver();

            var response = await _dataExchangeClient.ExecuteAsync<DataExchangeResponseDto>(config.BaseUrl + dto.Path, dto.HttpMethod, dto.Request, cancellationToken);

            //如果推送成功修改数据状态
            if (response != null)
            {
                //看看需不需要处理一些信息
                dto.LastTime = DateTime.Now;
                dto.SendTimes = dto.SendTimes++;

                if (dto.FirstTime is null)
                    dto.FirstTime = DateTime.Now;

                if (response.Code == "1")
                    dto.IsSuccess = true;

                await _dsSendTaskRepository.UpdateAsync(dto, cancellationToken);
            }
        }
    }
}
