﻿using Microsoft.Extensions.Logging;
using Quartz;
using XF.Domain.Queues;

namespace DataSharing.SendTask
{
    public class TaskExecuteJob : IJob, IDisposable
    {
        private readonly IQueue _queue;
        private readonly ILogger<TaskExecuteJob> _logger;
        private readonly ISendTaskDataService _sendTaskDataService;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="queue"></param>
        /// <param name="logger"></param>
        /// <param name="sendTaskDataService"></param>
        public TaskExecuteJob(IQueue queue, ILogger<TaskExecuteJob> logger, ISendTaskDataService sendTaskDataService)
        {
            _queue = queue;
            _logger = logger;
            _sendTaskDataService = sendTaskDataService;
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="context"></param>
        /// <returns></returns>
        public async Task Execute(IJobExecutionContext context)
        {
            var task = await _queue.DequeueAsync<DsSendTask>(SendTaskDefaults.SendTaskQueue, context.CancellationToken);
            if (task is not null)
            {
               // if (task.PlatformSource == Share.Enums.EPlatformSource.CityDataExchange)
                    await _sendTaskDataService.SendTask(task, context.CancellationToken);
                //_logger.LogInformation($"send task execute, taskId: {task.Id}");
            }
        }

        /// <summary>
        /// 
        /// </summary>
        public void Dispose()
        {
            //_logger.LogInformation($"execute job disposing");
        }
    }
}